pub struct TableStyle {Show 13 fields
pub border_style: BorderStyle,
pub border_width: f32,
pub border_color: Color,
pub background_color: Option<Color>,
pub padding: Padding,
pub font_name: String,
pub default_font_size: f32,
pub page_height: Option<f32>,
pub top_margin: f32,
pub bottom_margin: f32,
pub repeat_headers: bool,
pub embedded_font_resource_name: Option<String>,
pub embedded_font_resource_name_bold: Option<String>,
}Expand description
Styling for the entire table
Fields
border_style: BorderStyleborder_width: f32border_color: Colorbackground_color: Option<Color>padding: Paddingfont_name: StringDefault font for the table
default_font_size: f32page_height: Option<f32>Page height for pagination (if None, uses standard A4: 842 points)
top_margin: f32Top margin for pages
bottom_margin: f32Bottom margin for pages
repeat_headers: boolWhether to repeat header rows on new pages
embedded_font_resource_name: Option<String>PDF resource name for an embedded font (e.g., “EF0”).
When set together with font_metrics on the Table, text will be
encoded as glyph IDs and rendered using this font resource.
embedded_font_resource_name_bold: Option<String>PDF resource name for a bold embedded font (e.g., “EF0B”). When set and a cell is marked bold, this font resource is used.